module top(
//--------------Clocks------------------
input          clkin_50,		//2.5V	//Bank 8B  
//--------------User-IO-----------------
output[7:0]		user_led,		//LED
input [7:0]		user_dipsw,		//2.5V
input [3:0]		user_pb,			//

output[7:0] 	hsma_tx_d,		//Port A
output[7:0] 	hsmb_tx_d,		//Port B

input	[7:0] 	hsma_rx_d,		//Port A
input	[7:0] 	hsmb_rx_d		//Port B


);

//--------------WIRES-------------------
wire				clk_200m;		//PLL
wire				clk_for_led;	//PLL
wire				clk_for_genchk;//PLL
wire	[7:0]		gendata;			//data transmission
wire	[7:0]		txdata;			//data transmission
wire	[7:0]		rxdata;			//data transmission
wire				ct_en;			//enabling/disabling signal
wire				sec;				//clock by sec(or shorter)
wire	[7:0]		led;				//led showing test and error detection in progress
wire				err;				//error detection


//------------------------------------------------//
//******* USER PLL *******************************//
//------------------------------------------------//
pll	pll				(
							.inclk0 		(clkin_50),
							.c0 			(clk_200m),
							.c1 			(clk_for_led),
							.c2 			(clk_for_genchk),
							.locked		(locked)
							);

//------------------------------------------------//
//******* SELECTOR *******************************//
//------------------------------------------------//
sel_port	sel_port		(
							.sw 			(user_dipsw[7]),
							.tx_in 		(txdata),
							.hsma_tx 	(hsma_tx_d),
							.hsmb_tx 	(hsmb_tx_d),
							.hsma_rx		(hsma_rx_d),
							.hsmb_rx		(hsmb_rx_d),
							.rx_out		(rxdata)
							);

	
//------------------------------------------------//
//******* GENERATOR ******************************//
//------------------------------------------------//
gen	gen				(
							.clk			(clk_for_genchk),
							.rst			(locked),
							.ct_en		(ct_en),
							.q				(txdata)
							);

//------------------------------------------------//
//******* CHECKER ********************************//
//------------------------------------------------//
chk	chk				(
							.clk			(clk_for_genchk),
							.rst			(locked),
							.tx			(txdata),
							.rx			(rxdata),
							.fb			(ct_en),
							.err			(err)
							);

//------------------------------------------------//
//******* SEC. GENERATOR *************************//
//------------------------------------------------//
visible	visible		(
							.clk			(clk_for_led), 
							.rst			(locked),
							.sec			(sec)
							);	

//------------------------------------------------//
//******* TEST IN PROGRESS ***********************//
//------------------------------------------------//
testing	testing		(
							.clk			(clk_for_led), 
							.rst			(locked),
							.en			(ct_en),
							.sec			(sec),
							.led			(led[3:0])
							);							

assign user_led[0] = !led[0];
assign user_led[1] = !led[1];
assign user_led[2] = !led[2];
assign user_led[3] = !led[3];

//------------------------------------------------//
//******* ERROR COUNTER **************************//
//------------------------------------------------//
error_ctr	error_ctr(
							.clk			(clk_for_led),
							.rst			(locked),
							.sec			(sec),
							.err			(err),
							.led			(led[7:4])
							);

assign user_led[4] = !led[4];
assign user_led[5] = !led[5];
assign user_led[6] = !led[6];
assign user_led[7] = !led[7];

endmodule
